@@ -63,15 +63,15 @@ class TestCorpusManager(unittest.TestCase):
         cm.load_from_wb_database(db_name=db_config["wb_database"]["db_name"], db_user=db_config["wb_database"]["db_user"],
                                  db_password=db_config["wb_database"]["db_password"],
                                  db_host=db_config["wb_database"]["db_host"],
-                                 tazendra_ssh_user=tazendra_config["ssh"]["ssh_user"],
-                                 tazendra_ssh_passwd=tazendra_config["ssh"]["ssh_password"], max_num_papers=2)
+                                 ssh_user=tazendra_config["ssh"]["ssh_user"],
+                                 ssh_passwd=tazendra_config["ssh"]["ssh_password"], max_num_papers=2)
         self.assertTrue(cm.size() == 2)
         cm.load_from_wb_database(db_name=db_config["wb_database"]["db_name"],
                                  db_user=db_config["wb_database"]["db_user"],
                                  db_password=db_config["wb_database"]["db_password"],
                                  db_host=db_config["wb_database"]["db_host"],
-                                 tazendra_ssh_user=tazendra_config["ssh"]["ssh_user"],
-                                 tazendra_ssh_passwd=tazendra_config["ssh"]["ssh_password"], max_num_papers=2,
+                                 ssh_user=tazendra_config["ssh"]["ssh_user"],
+                                 ssh_passwd=tazendra_config["ssh"]["ssh_password"], max_num_papers=2,
                                  exclude_temp_pdf=True)
         self.assertFalse(any([paper.is_temp() for paper in cm.get_all_papers()]))
 
@@ -85,8 +85,8 @@ class TestCorpusManager(unittest.TestCase):
                                  db_user=db_config["wb_database"]["db_user"],
                                  db_password=db_config["wb_database"]["db_password"],
                                  db_host=db_config["wb_database"]["db_host"],
-                                 tazendra_ssh_user=tazendra_config["ssh"]["ssh_user"],
-                                 tazendra_ssh_passwd=tazendra_config["ssh"]["ssh_password"], max_num_papers=2,
+                                 ssh_user=tazendra_config["ssh"]["ssh_user"],
+                                 ssh_passwd=tazendra_config["ssh"]["ssh_password"], max_num_papers=2,
                                  load_curation_info=True, load_afp_info=True,
                                  exclude_temp_pdf=True, exclude_afp_processed=True, must_be_autclass_flagged=True)
         self.assertFalse(any([paper.afp_processed for paper in cm.get_all_papers()]))
