@@ -109,6 +109,7 @@ class WBPaper(object):
         self.afp_final_submission = False
         self.afp_processed = False
         self.afp_partial_submission = False
+        self.afp_contact_emails = []
         self.db_manager = db_manager
 
     def get_corresponding_author(self) -> Union[WBAuthor, None]:
@@ -240,7 +241,6 @@ class WBPaper(object):
             self.abstract = self.db_manager.get_paper_abstract(self.paper_id)
             self.title = self.db_manager.get_paper_title(self.paper_id)
             self.journal = self.db_manager.get_paper_journal(self.paper_id)
-            self.abstract = self.db_manager.get_paper_abstract(self.paper_id)
             self.pub_date = self.db_manager.get_paper_pub_date(self.paper_id)
             self.authors = self.db_manager.get_paper_authors(self.paper_id)
             self.doi = self.db_manager.get_doi(self.paper_id)
@@ -252,21 +252,23 @@ class WBPaper(object):
                               paper_ids_full_submission: List[str] = None,
                               paper_ids_partial_submission: List[str] = None):
         """load AFP data from WormBase database"""
+        if self.db_manager:
+            afp_db_manager = self.db_manager.get_db_manager(cls=WBAFPDBManager)
+        else:
+            raise Exception("PaperDBManager not set")
         if not paper_ids_no_submission or not paper_ids_full_submission or not paper_ids_partial_submission:
-            if self.db_manager:
-                afp_db_manager = self.db_manager.get_db_manager(cls=WBAFPDBManager)
-                if not paper_ids_no_submission:
-                    paper_ids_no_submission = afp_db_manager.get_paper_ids_afp_no_submission()
-                if not paper_ids_full_submission:
-                    paper_ids_full_submission = afp_db_manager.get_paper_ids_afp_full_submission()
-                if not paper_ids_partial_submission:
-                    paper_ids_partial_submission = afp_db_manager.get_paper_ids_afp_partial_submission()
-            else:
-                raise Exception("PaperDBManager not set")
+            afp_db_manager = self.db_manager.get_db_manager(cls=WBAFPDBManager)
+            if not paper_ids_no_submission:
+                paper_ids_no_submission = afp_db_manager.get_paper_ids_afp_no_submission()
+            if not paper_ids_full_submission:
+                paper_ids_full_submission = afp_db_manager.get_paper_ids_afp_full_submission()
+            if not paper_ids_partial_submission:
+                paper_ids_partial_submission = afp_db_manager.get_paper_ids_afp_partial_submission()
         self.afp_processed = self.paper_id in (set(paper_ids_no_submission) | set(paper_ids_full_submission) |
                                                set(paper_ids_full_submission))
         self.afp_partial_submission = self.paper_id in paper_ids_partial_submission
         self.afp_final_submission = self.paper_id in paper_ids_full_submission
+        self.afp_contact_emails = afp_db_manager.get_contact_emails(paper_id=self.paper_id)
 
     def has_same_wbpaper_id_as_filename(self, filename):
         return self._get_matches_from_filename(filename)[0] == self.paper_id
@@ -323,21 +325,23 @@ class WBPaper(object):
     def get_aut_class_value_for_datatype(self, datatype: str):
         return self.aut_class_values[datatype] if self.aut_class_values[datatype] else None
 
-    def get_first_author_with_email_address_in_wb(self, blacklisted_email_addresses: List[str] = None) -> \
-            Union[Tuple[WBAuthor, str], None]:
+    def get_authors_with_email_address_in_wb(self, blacklisted_email_addresses: List[str] = None,
+                                             first_only: bool = False) -> Union[List[Tuple[WBAuthor, str]], None]:
         """
         Get the first email address in the paper with a corresponding person entry in WB and return the person object
         and the email address found in the paper, which may be more recent than the one in WB
 
         Args:
             blacklisted_email_addresses (List[str]): a list of email addresses to be excluded from the search
+            first_only (bool): whether to return only the first available author
 
         Returns:
-            Union[Tuple[WBPerson, str], None]: a tuple containing the WBPerson and the email address found in the paper.
+            Union[List[Tuple[WBPerson, str]], None]: a tuple containing the WBPerson and the email address found in the paper.
                                                If no email is found with a corresponding person in WB, then the function
                                                will return the corresponding author associated with the paper in WB and
                                                its email address, if any, otherwise None.
         """
+        result = []
         all_addresses = self.extract_all_email_addresses_from_text()
         if not all_addresses:
             all_addresses = self.extract_all_email_addresses_from_text(self.get_text_docs(
@@ -350,9 +354,22 @@ class WBPaper(object):
                         WBPersonDBManager).get_person_id_from_email_address(address)
                     if person_id:
                         # curr_address = db_manager.get_current_email_address_for_person(person_id)
-                        return (self.db_manager.get_db_manager(WBPersonDBManager).get_person(person_id=person_id),
-                                address)
-        corresponding_author = self.get_corresponding_author()
-        if corresponding_author:
-            return corresponding_author, corresponding_author.email
-        return None
+                        if first_only:
+                            result = (self.db_manager.get_db_manager(WBPersonDBManager).get_person(person_id=person_id),
+                                      address)
+                        else:
+                            result.append((self.db_manager.get_db_manager(WBPersonDBManager).get_person(
+                                person_id=person_id), address))
+        if not result:
+            if first_only:
+                corresponding_author = self.get_corresponding_author()
+                if corresponding_author:
+                    result = corresponding_author, corresponding_author.email
+            else:
+                for author in self.authors:
+                    if author.email:
+                        result.append((author, author.email))
+        if result:
+            return result
+        else:
+            return None
